==> hooks-1.1.22.tgz: package/es/hooks/use-theme/theme-context.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React, { useImperativeHandle, useMemo, useState } from 'react';
import { createContext } from 'react';
var ETheme;
(function (ETheme) {
  ETheme["dark"] = "dark";
  ETheme["light"] = "light";
})(ETheme || (ETheme = {}));
export var ThemeContext = /*#__PURE__*/createContext({});
export var Theme = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var children = props.children;
  var _useState = useState(),
    _useState2 = _slicedToArray(_useState, 2),
    theme = _useState2[0],
    setTheme = _useState2[1];
  useImperativeHandle(ref, function () {
    return {
      setTheme: setTheme
    };
  });
  var memorizedThemeForm = useMemo(function () {
    return {
      theme: theme,
      setTheme: setTheme
    };
  }, [theme, setTheme]);
  return /*#__PURE__*/React.createElement(ThemeContext.Provider, {
    value: memorizedThemeForm
  }, children);
});

==> hooks-1.1.24.tgz: package/es/hooks/use-theme/theme-context.js <==
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t.return && (u = t.return(), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import React, { useImperativeHandle, useMemo, useState } from 'react';
import { createContext } from 'react';
var ETheme;
(function (ETheme) {
  ETheme["dark"] = "dark";
  ETheme["light"] = "light";
})(ETheme || (ETheme = {}));
export var ThemeContext = /*#__PURE__*/createContext({
  config: {}
});
export var Theme = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var children = props.children;
  var _useState = useState(),
    _useState2 = _slicedToArray(_useState, 2),
    theme = _useState2[0],
    setTheme = _useState2[1];
  var _useState3 = useState({}),
    _useState4 = _slicedToArray(_useState3, 2),
    config = _useState4[0],
    setConfig = _useState4[1];
  useImperativeHandle(ref, function () {
    return {
      setTheme: setTheme,
      setConfig: setConfig
    };
  });
  var memorizedThemeForm = useMemo(function () {
    return {
      theme: theme,
      setTheme: setTheme,
      config: config,
      setConfig: setConfig
    };
  }, [theme, config]);
  return /*#__PURE__*/React.createElement(ThemeContext.Provider, {
    value: memorizedThemeForm
  }, children);
});
